inline void EncryptBuf::eoi()
{}
